@@ -9,11 +9,12 @@
 
 using namespace Rcpp;
 
-RcppExport SEXP readDirectory (SEXP path_, SEXP flipY_, SEXP crop_, SEXP forceStack_, SEXP verbosity_, SEXP labelFormat_, SEXP singleFile_, SEXP scanOnly_)
+RcppExport SEXP readDirectory (SEXP path_, SEXP flipY_, SEXP crop_, SEXP forceStack_, SEXP verbosity_, SEXP labelFormat_, SEXP singleFile_, SEXP depth_, SEXP task_, SEXP outputDir_)
 {
 BEGIN_RCPP
     const std::string path = as<std::string>(path_);
     const std::string labelFormat = as<std::string>(labelFormat_);
+    const std::string task = as<std::string>(task_);
     
     TDCMopts options;
     setDefaultOpts(&options, NULL);
@@ -26,11 +27,18 @@ BEGIN_RCPP
     options.isForceStackSameSeries = as<bool>(forceStack_);
     options.isCrop = as<bool>(crop_);
     options.isOnlySingleFile = as<bool>(singleFile_);
-    options.isScanOnly = as<bool>(scanOnly_);
+    options.isScanOnly = (task == "scan");
+    options.isRenameNotConvert = (task == "sort");
     options.isVerbose = as<int>(verbosity_);
+    options.dirSearchDepth = as<int>(depth_);
     options.compressFlag = kCompressYes;
     strcpy(options.indir, path.c_str());
     strcpy(options.filename, labelFormat.c_str());
+    if (task == "sort" && !Rf_isNull(outputDir_))
+    {
+        const std::string outputDir = as<std::string>(outputDir_);
+        strcpy(options.outdir, outputDir.c_str());
+    }
     
     ImageList images;
     options.imageList = (void *) &images;
@@ -122,16 +130,20 @@ BEGIN_RCPP
             info.attr("class") = CharacterVector::create("divest","data.frame");
             return info;
         }
+        else if (options.isRenameNotConvert)
+            return List::create(Named("source")=options.sourcePaths, Named("target")=options.targetPaths, Named("ignored")=options.ignoredPaths);
         else
             return images;
     }
+    else if (returnValue == kEXIT_NO_VALID_FILES_FOUND)
+        Rprintf("No valid DICOM files found\n");
     else
         Rf_error("DICOM scan failed");
 END_RCPP
 }
 
 static const R_CallMethodDef callMethods[] = {
-  { "readDirectory", (DL_FUNC) &readDirectory, 8 },
+  { "readDirectory", (DL_FUNC) &readDirectory, 10 },
   { NULL, NULL, 0 }
 };
 
